===================================================
Plette: Structured Pipfile and Pipfile.lock models.
===================================================

.. image:: https://img.shields.io/pypi/v/plette.svg
    :target: https://pypi.org/pypi/plette

.. image:: https://img.shields.io/pypi/l/plette.svg
    :target: https://pypi.org/pypi/plette

.. image:: https://api.travis-ci.com/sarugaku/plette.svg?branch=master
    :target: https://travis-ci.com/sarugaku/plette

.. image:: https://img.shields.io/pypi/pyversions/plette.svg
    :target: https://pypi.org/pypi/plette

.. image:: https://readthedocs.org/projects/plette/badge/?version=master
    :target: http://plette.readthedocs.io/en/master/?badge=master
    :alt: Documentation Status

Plette implements Pipfile and Pipfile.lock parsers, generators, and optional
validators to let the user work with them in a structured manner.


Installation
============

Install with pip::

    pip install plette

Install with the optional validation feature::

    pip install plette[validation]


`Read the documentation <https://plette.readthedocs.io>`__.
